sievetools.ResidueClassExpression
=================================

.. abjad-lineage:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression

.. autoclass:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.operator
   :noindex:

.. autoattribute:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.period
   :noindex:

.. autoattribute:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.rcs
   :noindex:

.. autoattribute:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.representative_boolean_train
   :noindex:

.. autoattribute:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.representative_congruent_bases
   :noindex:

.. autoattribute:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.storage_format
   :noindex:

Methods
-------

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.get_boolean_train
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.get_congruent_bases
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.is_congruent_base
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__and__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__eq__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__ge__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__gt__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__le__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__lt__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__ne__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__or__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__repr__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClassExpression.ResidueClassExpression.ResidueClassExpression.__xor__
   :noindex:
